﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using ThinkGeo.MapSuite.Core;
using System.Collections.ObjectModel;

namespace SampleApp_MS3_7583
{
    public class MyPointStyle: PointStyle
    {
        public ZoomLevelSet ZoomLevels { get; set; }
        public MyPointStyle(string sImagePath, ZoomLevelSet zoomLevels)
            : base()
        {
            this.Image = new GeoImage(sImagePath);
            this.ImageScale = 0.3;
            this.IsActive = true;

            ZoomLevels = zoomLevels;

           

            this.PointType = ThinkGeo.MapSuite.Core.PointType.Bitmap;
        }

    
        protected override void DrawCore(IEnumerable<Feature> features, GeoCanvas canvas, System.Collections.ObjectModel.Collection<SimpleCandidate> labelsInThisLayer, System.Collections.ObjectModel.Collection<SimpleCandidate> labelsInAllLayers)
        {
        
            int zoomLevel = GetCurrentZoomLevel(canvas.CurrentWorldExtent, canvas.Width, canvas.MapUnit);


            foreach (Feature f in features)
            {
                //string[] arr = f.Tag.ToString().Split("#".ToCharArray());
                //float angle = 0;
                //float.TryParse(arr[0], out angle);

                //int fromZoomLevel = int.Parse(arr[1]);
                //PointShape location = (PointShape)f.GetShape();

                //if (fromZoomLevel <= zoomLevel)
                //    canvas.DrawWorldImage(this.Image, location.X, location.Y, 0.5, DrawingLevel.LevelFour, 0, 0, -angle);

                string[] arr = f.Tag.ToString().Split('#');
                float angle = Convert.ToSingle(arr[0]);

                int fromZoomLevel = Convert.ToInt32(arr[1]);
                double centerX = BitConverter.ToDouble(f.WellKnownBinary, 5);
                double centerY = BitConverter.ToDouble(f.WellKnownBinary, 13);

                if (fromZoomLevel <= zoomLevel)
                {
                    canvas.DrawWorldImage(this.Image, centerX, centerY, 0.5, DrawingLevel.LevelFour, 0, 0, -angle);
                }

            }

           
          
        }

        public  int GetCurrentZoomLevel(RectangleShape CurrentExtent, double mapWidth, GeographyUnit mapUnit)
        {

            // Get the zoomLevel based on the current extent. 
            ZoomLevel myLevel = ZoomLevels.GetZoomLevel(CurrentExtent, mapWidth, mapUnit);

            // Get the number(1 to 20) of the current zoomLevel.
            Collection<ZoomLevel> zoomLevels = ZoomLevels.GetZoomLevels();

            int currentZoomLevelNumber = 0;
            for (int i = 0; i < 20; i++)
            {
                if (zoomLevels != null && zoomLevels[i].Scale == myLevel.Scale)
                {
                    // Here we get the number of the current ZoomLevel
                    currentZoomLevelNumber = i + 1;
                    break;
                }
            }

            return currentZoomLevelNumber;

        }
    }


  
}
